@@ -281,7 +281,7 @@ def preprocess(
     x = x.select_dtypes(include=[int, float]).fillna(method='ffill').to_numpy()
     
     if target_col is not None:
-        y = df[target_col].fillna(mothod='ffill')
+        y = df[target_col].fillna(method='ffill')
         
         y = y.to_numpy().reshape(len(y), target_dim)
         
